<%inherit file="basewithmenu.html" /> <%block name="head"> ${parent.head()}
<%block name="menu2">
×

### Create classifier

Name:

Labels (comma separated):

Mode:

Processing

×

### Copy/Merge classifiers

Name:

From:

Select one ore more classifiers to merge.

If only one classifier is selected, a simple copy is made.

If multiple classifiers are selected, their labels are merged together.

Mode:

Processing

×

### Upload labeled documents

Data file:

Data file is a CSV file with at least two columns.

First column contains a unique ID string.

Second column contains the text.

Any column after the second is the assignment of a label.

For single-label classifiers, the assignment has the form classifiername:labelname, with the implicit information that the text is a negative example for any other label defined for the classifier.

For multi-label classifiers, the assignment has the form classifiername:labelname:yes or classifiername:labelname:yes

. No implicit information derives from this assignment with respect to the other labels of the classifier.

If a classifier does not already exist, it is created with the classification mode used in the file, and set of labels appearing in the file.

If a classifier already exist, the uploaded data must use the same classification mode of the existing classifier, and cannot use labels that are not already defined in the existing classifier.

Uploading

×

### Upload a model

Name:

Model file:

Mode:

Uploading

×

### Rename a classifier

Classifier to rename:

New name:

Processing

×

### Change description

Classifier:

Description:

Processing

×

### Change classification mode

Classifier:

Mode:

Processing

×

### Rename a label in a classifier

Classifier:

Label to rename:

New label name:

Processing

×

### Add a label to a classifier

Classifier:

New label name:

Processing

×

### Delete a label in a classifier

Classifier:

Label to delete:

Processing

×

### Delete a classifier

Classifier to delete:

Processing

×

### Create a classifier from a label

Classifier:

Label to extract:

Processing